@@ -12,17 +12,32 @@ if [ "$(ls -A $original)" ]; then
             do
                 iko=`basename ${ikon}`
 
-                    if [ "${bild}" != "${iko}" ]; then                    	
+		if [ "${bild}" != "${iko}" ]; then                    	
                     	cp /usr/share/pixmaps/${iko} $original
-                    fi
-                    
+		fi
             done
         done
 else
 	mkdir $original
-	cp $pixmaps".png" $original
+	cp $pixmaps $original
 fi	
 
+if [ "$(ls -A /opt/multical-date-widget/" ]; then
+	if [ "$(ls -A /home/user/.awoken-extras/orig/calendar.png)" ]; then
+		echo ""
+	else 
+		cp /opt/multical-date-widget/calendar.png $original
+	fi
+fi
+
+if [ "$(ls -A /opt/tomch.com/" ]; then
+	if [ "$(ls -A /home/user/.awoken-extras/orig/tomch.com/)" ]; then
+		echo ""
+	else 
+		cp -r /opt/tomch.com/recaller/ $original
+	fi
+fi
+
 case "$1" in
     '-'[Cc] | '--change')
         for pics in $pixmaps
@@ -39,6 +54,8 @@ case "$1" in
                     
             done
         done
+        cp /usr/share/icons/awoken-icon-theme/extras/calendar-5.png /opt/multical-date-widget/calendar.png
+        cp /usr/share/icons/awoken-icon-theme/extras/recaller/* /opt/tomch.com/recaller/
     exit
     ;;
     '-'[Bb] | '--backup')
@@ -57,6 +74,11 @@ case "$1" in
                     
             done
         done
+	rm /opt/multical-date-widget/calendar.png.orig
+	rm /opt/tomch.com/recaller/*.orig
+	cp /opt/multical-date-widget/calendar.png /opt/multical-date-widget/calendar.png.orig
+	cp /opt/tomch.com/recaller/recaller_64.png /opt/tomch.com/recaller/recaller_64.png.orig
+	cp /opt/tomch.com/recaller/recaller_64_on.png /opt/tomch.com/recaller/recaller_64_on.png.orig
     exit
     ;;
     '-'[Rr] | '--reset')
@@ -74,6 +96,9 @@ case "$1" in
                     
             done
         done
+	mv /opt/multical-date-widget/calendar.png.orig /opt/multical-date-widget/calendar.png
+	mv /opt/tomch.com/recaller/recaller_64.png.orig /opt/tomch.com/recaller/recaller_64.png
+	mv /opt/tomch.com/recaller/recaller_64_on.png.orig /opt/tomch.com/recaller/recaller_64_on.png
     exit
     ;;
 esac
